@@ -8,7 +8,7 @@
 # @Software     : PyCharm
 # @Description  : 
 
-
+from meutils.path_utils import get_module_path
 from bertzoo.utils.bert4keras_utils import *
 
 
@@ -22,6 +22,14 @@ class SimBert(object):
         :param config_path:
         :param checkpoint_path:
         """
+        if dict_path is None:
+            p = get_module_path(f'../data/chinese_simbert_L-4_H-312_A-12.zip')
+            target = Path(p).parent / 'chinese_simbert_L-4_H-312_A-12'
+
+            os.system(f'cd {target} && unzip {p}')
+
+            dict_path = str(dict_path / 'vocab.txt')
+
         top_dir = Path(dict_path).parent
         if config_path is None:
             config_path = str(top_dir / 'bert_config.json')
@@ -79,34 +87,35 @@ class SynonymsGenerator(AutoRegressiveDecoder):
 
 
 if __name__ == '__main__':
-    sb = SimBert('/fds/data/bert/chinese_simbert_L-12_H-768_A-12/vocab.txt')
-    sb.build_model()
-
-    tokenizer = sb.tokenizer
-    encoder = sb.encoder
-    seq2seq = sb.seq2seq
-
-    sg = SynonymsGenerator(tokenizer=tokenizer, seq2seq=seq2seq)
-
-
-    def gen_synonyms(text, n=200, k=10):
-        """"含义： 产生sent的n个相似句，然后返回最相似的k个。
-        做法：用seq2seq生成，并用encoder算相似度并排序。
-        """
-        r = sg.generate(text, n)
-        r = [i for i in set(r) if i != text]
-        r = [text] + r
-        X, S = [], []
-        for t in r:
-            x, s = tokenizer.encode(t)
-            X.append(x)
-            S.append(s)
-        X = sequence_padding(X)
-        S = sequence_padding(S)
-        Z = encoder.predict([X, S])
-        Z /= (Z ** 2).sum(axis=1, keepdims=True) ** 0.5
-        argsort = np.dot(Z[1:], -Z[0]).argsort()
-        return [r[i + 1] for i in argsort[:k]]
-
-
-    gen_synonyms('支付宝')
+    # sb = SimBert('/fds/data/bert/chinese_simbert_L-12_H-768_A-12/vocab.txt')
+    # sb.build_model()
+    #
+    # tokenizer = sb.tokenizer
+    # encoder = sb.encoder
+    # seq2seq = sb.seq2seq
+    #
+    # sg = SynonymsGenerator(tokenizer=tokenizer, seq2seq=seq2seq)
+    #
+    #
+    # def gen_synonyms(text, n=200, k=10):
+    #     """"含义： 产生sent的n个相似句，然后返回最相似的k个。
+    #     做法：用seq2seq生成，并用encoder算相似度并排序。
+    #     """
+    #     r = sg.generate(text, n)
+    #     r = [i for i in set(r) if i != text]
+    #     r = [text] + r
+    #     X, S = [], []
+    #     for t in r:
+    #         x, s = tokenizer.encode(t)
+    #         X.append(x)
+    #         S.append(s)
+    #     X = sequence_padding(X)
+    #     S = sequence_padding(S)
+    #     Z = encoder.predict([X, S])
+    #     Z /= (Z ** 2).sum(axis=1, keepdims=True) ** 0.5
+    #     argsort = np.dot(Z[1:], -Z[0]).argsort()
+    #     return [r[i + 1] for i in argsort[:k]]
+    #
+    #
+    # gen_synonyms('支付宝')
+    SimBert()
