@@ -16,20 +16,18 @@ from bert4keras.backend import keras
 from bert4keras.models import build_transformer_model
 
 from bert4keras.tokenizers import Tokenizer
-from bert4keras.snippets import sequence_padding, DataGenerator
-
-maxlen = 128
+from bert4keras.snippets import sequence_padding, DataGenerator, AutoRegressiveDecoder
 
 
 @lru_cache(100000)
-def text2seq(text, tokenizer):
+def text2seq(text, tokenizer, maxlen=64):
     token_ids, segment_ids = tokenizer.encode(text, maxlen=maxlen)
     batch_token_ids = sequence_padding([token_ids], length=maxlen)
     batch_segment_ids = sequence_padding([segment_ids], length=maxlen)
     return batch_token_ids, batch_segment_ids
 
 
-def texts2seq(texts, tokenizer):
+def texts2seq(texts, tokenizer, maxlen=64):
     batch_token_ids, batch_segment_ids = [], []
     for text in texts:
         token_ids, segment_ids = tokenizer.encode(text, maxlen=maxlen)
